@@ -7,7 +7,7 @@ use Perl::Dist;
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '18';
+	$VERSION = '19';
 	@ISA     = 'Perl::Dist';
 }
 
@@ -87,30 +87,32 @@ sub install_perl_5100_bin {
 	$self->SUPER::install_perl_5100_bin(@_);
 
 	# Overwrite the CPAN config to be relocatable
-	$self->install_file(
-		share      => 'Perl-Dist vanilla/Config5100.pm',
-		install_to => 'perl/lib/Config.pm',
-	);
-	$self->install_file(
-		share      => 'Perl-Dist vanilla/Config_heavy5100.pl',
-		install_to => 'perl/lib/Config_heavy.pl',
-	);
-	$self->install_file(
-		share      => 'Perl-Dist vanilla/CPAN_Config.pm',
-		install_to => 'perl/lib/CPAN/Config.pm',
-	);
+	if ( $self->portable ) {
+		$self->install_file(
+			share      => 'Perl-Dist vanilla/perl-5.10.0/lib/Config.pm',
+			install_to => 'perl/lib/Config.pm',
+		);
+		$self->install_file(
+			share      => 'Perl-Dist vanilla/perl-5.10.0/lib/Config_heavy.pl',
+			install_to => 'perl/lib/Config_heavy.pl',
+		);
+		$self->install_file(
+			share      => 'Perl-Dist vanilla/perl-5.10.0/lib/CPAN/Config.pm',
+			install_to => 'perl/lib/CPAN/Config.pm',
+		);
+	}
 
 	return 1;
 }
 
-sub install_perl_5100_toolchain_object {
-	Perl::Dist::Util::Toolchain->new(
-		perl_version => $_[0]->perl_version_literal,
-		force        => {
-			'File::Path' => 'DLAND/File-Path-2.04.tar.gz',
-			# 'CPAN'       => 'ANDK/CPAN-1.92_60.tar.gz',
-		},
-	);
+sub install_c_libraries {
+	my $self = shift;
+	$self->SUPER::install_c_libraries(@_);
+
+	# Install Expat (which exercises install_par)
+	$self->install_expat;
+
+	return 1;
 }
 
 sub install_perl_modules {
@@ -145,6 +147,22 @@ sub remove_waste {
 	return 1;
 }
 
+sub patch_include_path {
+	my $self    = shift;
+	my $include = $self->SUPER::patch_include_path;
+
+	# Add the extra vanilla directory
+	my $perl  = $self->perl_version_human;
+	my $share = File::ShareDir::dist_dir('Perl-Dist');
+	my $path  = File::Spec->catdir(
+		$share, 'vanilla',
+	);
+	unless ( -d $path ) {
+		die("Directory $path does not exist");
+	}
+	return [ @$include, $path ];
+}
+
 1;
 
 __END__
@@ -247,18 +265,6 @@ Once installed, you should add to the following environment variables.
         - C:\vanilla\c\bin
         - C:\vanilla\perl\bin 
 
-    * add directories to LIB
-        - C:\vanilla\c\lib
-        - C:\vanilla\perl\bin
-
-    * add directories to INCLUDE 
-        - C:\vanilla\c\include 
-        - C:\vanilla\perl\lib\CORE 
-
-LIB and INCLUDE changes are likely more than are necessary, but attempt to
-head off potential problems compiling external programs for use with Perl
-and various CPAN modules.
-
 The "cpan" program is pre-configured with a known-good setup, but you may
 wish to reconfigure it.
 
